@@ -37,21 +37,23 @@ def open_rm_inputs(*, address, key, password):
     client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
 
     pkey = None
-    password = None
 
     agent = paramiko.agent.Agent()
 
     def use_key(key):
-        try:
-            pkey = paramiko.RSAKey.from_private_key_file(os.path.expanduser(key))
-        except paramiko.ssh_exception.PasswordRequiredException:
-            passphrase = getpass(
-                "Enter passphrase for key '{}': ".format(os.path.expanduser(key))
-            )
-            pkey = paramiko.RSAKey.from_private_key_file(
-                os.path.expanduser(key),
-                password=passphrase
-            )
+        for key_type in [paramiko.RSAKey, paramiko.Ed25519Key, paramiko.ECDSAKey]:
+            try:
+                pkey = key_type.from_private_key_file(os.path.expanduser(key))
+            except paramiko.ssh_exception.SSHException:
+                continue
+            except paramiko.ssh_exception.PasswordRequiredException:
+                passphrase = getpass(
+                    "Enter passphrase for key '{}': ".format(os.path.expanduser(key))
+                )
+                pkey = paramiko.RSAKey.from_private_key_file(
+                    os.path.expanduser(key), password=passphrase
+                )
+                break
         return pkey
 
     if key is not None:
@@ -60,7 +62,7 @@ def open_rm_inputs(*, address, key, password):
     elif os.path.exists(default_key):
         password = None
         pkey = use_key(default_key)
-    elif password:
+    elif password is not None:
         pkey = None
     elif not agent.get_keys():
         password = getpass(
@@ -73,7 +75,8 @@ def open_rm_inputs(*, address, key, password):
         username='root',
         password=password,
         pkey=pkey,
-        look_for_keys=False
+        look_for_keys=False,
+        disabled_algorithms=dict(pubkeys=["rsa-sha2-512", "rsa-sha2-256"])
     )
 
     session = client.get_transport().open_session()
@@ -112,9 +115,13 @@ def main():
         parser.add_argument('--key', type=str, metavar='PATH', help="ssh private key")
         parser.add_argument('--password', default=None, type=str, help="ssh password")
         parser.add_argument('--address', default='10.11.99.1', type=str, help="device address")
-        parser.add_argument('--mode', default='fill', choices=['fit', 'fill'], help="scale setting")
-        parser.add_argument('--orientation', default='right', choices=['top', 'left', 'right', 'bottom'], help="position of charging port")
+        parser.add_argument('--mode', default='fill', choices=['fit', 'fill', 'stretch'], help="""Scale setting.
+        Fit (default): take up the entire tablet, but not necessarily the entire monitor.
+        Fill: take up the entire monitor, but not necessarily the entire tablet.
+        Stretch: take up both the entire tablet and monitor, but don't maintain aspect ratio.""")
+        parser.add_argument('--orientation', default='right', choices=['top', 'left', 'right', 'bottom'], help="position of tablet buttons")
         parser.add_argument('--monitor', default=0, type=int, metavar='NUM', help="monitor to output to")
+        parser.add_argument('--region', action='store_true', default=False, help="Use a GUI to position the output area. Overrides --monitor")
         parser.add_argument('--threshold', metavar='THRESH', default=600, type=int, help="stylus pressure threshold (default 600)")
         parser.add_argument('--evdev', action='store_true', default=False, help="use evdev to support pen pressure (requires root, Linux only)")
 
@@ -146,7 +153,8 @@ def main():
         read_tablet(
             rm_inputs,
             orientation=args.orientation,
-            monitor=args.monitor,
+            monitor_num=args.monitor,
+            region=args.region,
             threshold=args.threshold,
             mode=args.mode,
         )
